summaryrefslogtreecommitdiff
path: root/src/lib
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2015-07-29 20:54:27 +0100
committerCarl Hetherington <cth@carlh.net>2015-07-29 20:54:27 +0100
commite45aaf708967630b71323c2eccbb0ab2a5497c17 (patch)
tree425bc8febd0ad21639763abc9e98202f20a00845 /src/lib
parent5bce9837a15647bc07977be0c304f5bd0bf212c2 (diff)
Move code to create DCPContent or (non-still) ImageContent into content_factory().
Diffstat (limited to 'src/lib')
-rw-r--r--src/lib/content_factory.cc60
1 files changed, 41 insertions, 19 deletions
diff --git a/src/lib/content_factory.cc b/src/lib/content_factory.cc
index 3c65b4312..c61889363 100644
--- a/src/lib/content_factory.cc
+++ b/src/lib/content_factory.cc
@@ -66,9 +66,9 @@ content_factory (shared_ptr<const Film> film, cxml::NodePtr node, int version, l
return content;
}
/** Create a Content object from a file, depending on its extension.
* @param film Film that the content will be in.
- * @param path File's path.
+ * @param path File or directory.
* @return Content object.
*/
shared_ptr<Content>
@@ -76,23 +76,45 @@ content_factory (shared_ptr<const Film> film, boost::filesystem::path path)
{
shared_ptr<Content> content;
- string ext = path.extension().string ();
- transform (ext.begin(), ext.end(), ext.begin(), ::tolower);
-
- if (valid_image_file (path)) {
- content.reset (new ImageContent (film, path));
- } else if (SndfileContent::valid_file (path)) {
- content.reset (new SndfileContent (film, path));
- } else if (ext == ".srt") {
- content.reset (new SubRipContent (film, path));
- } else if (ext == ".xml") {
- content.reset (new DCPSubtitleContent (film, path));
- } else if (ext == ".mxf" && dcp::SMPTESubtitleAsset::valid_mxf (path)) {
- content.reset (new DCPSubtitleContent (film, path));
- }
-
- if (!content) {
- content.reset (new FFmpegContent (film, path));
+ if (boost::filesystem::is_directory (path)) {
+ /* Guess if this is a DCP or a set of images: read the first ten filenames and if they
+ are all valid image files we assume it is a set of images.
+ */
+
+ bool is_dcp = false;
+ int read = 0;
+ for (boost::filesystem::directory_iterator i(path); i != boost::filesystem::directory_iterator() && read < 10; ++i, ++read) {
+ if (!boost::filesystem::is_regular_file (i->path()) || !valid_image_file (i->path())) {
+ is_dcp = true;
+ }
+ }
+
+ if (is_dcp) {
+ content.reset (new DCPContent (film, path));
+ } else {
+ content.reset (new ImageContent (film, path));
+ }
+
+ } else {
+
+ string ext = path.extension().string ();
+ transform (ext.begin(), ext.end(), ext.begin(), ::tolower);
+
+ if (valid_image_file (path)) {
+ content.reset (new ImageContent (film, path));
+ } else if (SndfileContent::valid_file (path)) {
+ content.reset (new SndfileContent (film, path));
+ } else if (ext == ".srt") {
+ content.reset (new SubRipContent (film, path));
+ } else if (ext == ".xml") {
+ content.reset (new DCPSubtitleContent (film, path));
+ } else if (ext == ".mxf" && dcp::SMPTESubtitleAsset::valid_mxf (path)) {
+ content.reset (new DCPSubtitleContent (film, path));
+ }
+
+ if (!content) {
+ content.reset (new FFmpegContent (film, path));
+ }
}
return content;
@@ -66,9 +66,9 @@ content_factory (shared_ptr<const Film> film, cxml::NodePtr node, int version, l
return content;
}
-/** Create a Content object from a file, depending on its extension.
+/** Create a Content object from a file or directory.
* @param film Film that the content will be in.